<?php
/**
 * Backdrop Filter Group Control Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\Elementor\Controls;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use \Elementor\Group_Control_Base;
use \Elementor\Controls_Manager;

/**
 * Backrop Filter Group Control Class
 */
class Backdrop_Filter extends Group_Control_Base {
	/**
	 * Fields.
	 *
	 * Holds all the backdrop filter control fields.
	 *
	 * @access protected
	 * @static
	 *
	 * @var array Backdrop filter control fields.
	 */
	protected static $fields;

	/**
	 * Get backdrop filter control type.
	 *
	 * Retrieve the control type, in this case `backdrop_filter`.
	 *
	 * @access public
	 * @static
	 *
	 * @return string Control type.
	 */
	public static function get_type() {
		return 'backdrop_filter';
	}

	/**
	 * Init fields.
	 *
	 * Initialize backdrop filter control fields.
	 *
	 * @access public
	 *
	 * @return array Control fields.
	 */
	public function init_fields() {
		$fields = array();

		$fields['blur'] = array(
			'label'       => esc_html_x( 'Blur', 'Backdrop Filter Control', 'profecient-essential' ),
			'type'        => Controls_Manager::SLIDER,
			'size_units'  => array( 'px', '%' ),
			'range'       => array(
				'px' => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
			),
			'default'     => array(
				'unit' => 'px',
				'size' => 0,
			),
			'render_type' => 'ui',
			'selectors'   => array(
				'{{SELECTOR}}' => 'backdrop-filter: blur( {{blur.SIZE}}{{blur.unit}} ) brightness( {{brightness.SIZE}} ) contrast( {{contrast.SIZE}} ) grayscale( {{grayscale.SIZE}} ) hue-rotate( {{hue_rotate.SIZE}}deg ) opacity( {{opacity.SIZE}} ) sepia( {{sepia.SIZE}} ) saturate( {{saturate.SIZE}} );',
			),
			'description' => esc_html__( 'Default is 0', 'profecient-essential' ),
		);

		$fields['brightness'] = array(
			'label'       => esc_html_x( 'Brightness', 'Backdrop Filter Control', 'profecient-essential' ),
			'type'        => Controls_Manager::SLIDER,
			'range'       => array(
				'px' => array(
					'min'  => 0,
					'max'  => 10,
					'step' => 0.01,
				),
			),
			'default'     => array(
				'size' => 1,
			),
			'render_type' => 'ui',
			'description' => esc_html__( 'Default is 1', 'profecient-essential' ),
		);

		$fields['contrast'] = array(
			'label'       => esc_html_x( 'Contrast', 'Backdrop Filter Control', 'profecient-essential' ),
			'type'        => Controls_Manager::SLIDER,
			'range'       => array(
				'px' => array(
					'min'  => 0,
					'max'  => 10,
					'step' => 0.01,
				),
			),
			'default'     => array(
				'size' => 1,
			),
			'render_type' => 'ui',
			'description' => esc_html__( 'Default is 1', 'profecient-essential' ),
		);

		$fields['grayscale'] = array(
			'label'       => esc_html_x( 'Grayscale', 'Backdrop Filter Control', 'profecient-essential' ),
			'type'        => Controls_Manager::SLIDER,
			'range'       => array(
				'px' => array(
					'min'  => 0,
					'max'  => 1,
					'step' => 0.01,
				),
			),
			'default'     => array(
				'size' => 0,
			),
			'render_type' => 'ui',
			'description' => esc_html__( 'Default is 0', 'profecient-essential' ),
		);

		$fields['hue_rotate'] = array(
			'label'       => esc_html_x( 'Hue Rotate', 'Backdrop Filter Control', 'profecient-essential' ),
			'type'        => Controls_Manager::SLIDER,
			'range'       => array(
				'px' => array(
					'min'  => 0,
					'max'  => 360,
					'step' => 1,
				),
			),
			'default'     => array(
				'size' => 0,
			),
			'render_type' => 'ui',
			'description' => esc_html__( 'Default is 0', 'profecient-essential' ),
		);

		$fields['opacity'] = array(
			'label'       => esc_html_x( 'Opacity', 'Backdrop Filter Control', 'profecient-essential' ),
			'type'        => Controls_Manager::SLIDER,
			'range'       => array(
				'px' => array(
					'min'  => 0,
					'max'  => 1,
					'step' => 0.01,
				),
			),
			'default'     => array(
				'size' => 1,
			),
			'render_type' => 'ui',
			'description' => esc_html__( 'Default is 1', 'profecient-essential' ),
		);

		$fields['sepia'] = array(
			'label'       => esc_html_x( 'Sepia', 'Backdrop Filter Control', 'profecient-essential' ),
			'type'        => Controls_Manager::SLIDER,
			'range'       => array(
				'px' => array(
					'min'  => 0,
					'max'  => 1,
					'step' => 0.01,
				),
			),
			'default'     => array(
				'size' => 0,
			),
			'render_type' => 'ui',
			'description' => esc_html__( 'Default is 0', 'profecient-essential' ),
		);

		$fields['saturate'] = array(
			'label'       => esc_html_x( 'Saturate', 'Backdrop Filter Control', 'profecient-essential' ),
			'type'        => Controls_Manager::SLIDER,
			'range'       => array(
				'px' => array(
					'min'  => 0,
					'max'  => 10,
					'step' => 0.01,
				),
			),
			'default'     => array(
				'size' => 1,
			),
			'render_type' => 'ui',
			'description' => esc_html__( 'Default is 1', 'profecient-essential' ),
		);

		return $fields;
	}

	/**
	 * Get default options.
	 *
	 * Retrieve the default options of the backdrop filter control. Used to return the
	 * default options while initializing the backdrop filter control.
	 *
	 * @access protected
	 *
	 * @return array Default backdrop filter control options.
	 */
	protected function get_default_options() {
		return array(
			'popover' => array(
				'starter_title' => esc_html__( 'Backdrop Filter', 'profecient-essential' ),
				'starter_name'  => 'backdrop_filter_type',
				'starter_value' => 'yes',
				'settings'      => array(
					'render_type' => 'ui',
				),
			),
		);
	}
}
