<?php
/**
 * Breadcrumb Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\Helpers;

/**
 * Class Breadcrumb
 *
 * @package Profecient\Essential\Helpers\Breadcrumb
 */
class Breadcrumb {
	/**
	 * Class instance
	 *
	 * @var Asset
	 */
	private static $instance;

	/**
	 * Crumb Trail
	 *
	 * @var array
	 */
	protected $crumbs = array();

	/**
	 * Construct
	 */
	public function __construct() {
	}

	/**
	 * Get class instance
	 *
	 * @return Asset
	 */
	public static function instance() {
		if ( null === static::$instance ) {
			static::$instance = new static();
		}

		return static::$instance;
	}

	/**
	 * Get The Breadcrumb
	 */
	public function get_breadcrumb() {
		return apply_filters( 'profecient_get_breadcrumb', $this->crumbs, $this );
	}

	/**
	 * Generate Crumbs
	 */
	public function generate_crumbs() {
		$conditionals = array(
			// 'is_post_type_archive',
			'is_date',
			// 'is_category',
			// 'is_tag',
			// 'is_tax',
			'is_author',
			'is_archive',
			'is_attachment',
			'is_single',
			'is_page',
			'is_home',
			'is_404',
			'is_search',
		);

		$this->add_front_page_crumb();

		foreach ( $conditionals as $conditional ) {
			if ( call_user_func( $conditional ) ) {
				call_user_func( array( $this, 'add_' . substr( $conditional, 3 ) . '_crumb' ) );
				break;
			}
		}

		return $this->get_breadcrumb();
	}

	/**
	 * Add a Crumb to trail
	 *
	 * @param string $name Name.
	 * @param string $link Link.
	 */
	public function add_crumb( $name, $link = '' ) {
		$this->crumbs[] = array(
			'name' => wp_strip_all_tags( $name ),
			'url'  => $link,
		);
	}

	/**
	 * Add crumbs for a term.
	 *
	 * @param int    $term_id  Term ID.
	 * @param string $taxonomy Taxonomy.
	 */
	protected function term_ancestors( $term_id, $taxonomy ) {
		$ancestors = get_ancestors( $term_id, $taxonomy );
		$ancestors = array_reverse( $ancestors );

		foreach ( $ancestors as $ancestor ) {
			$ancestor = get_term( $ancestor, $taxonomy );

			if ( ! is_wp_error( $ancestor ) && $ancestor ) {
				$this->add_crumb( $ancestor->name, get_term_link( $ancestor ) );
			}
		}
	}

	/**
	 * Add Front Page Crumb
	 */
	public function add_front_page_crumb() {
		$this->add_crumb( esc_html__( 'Home' ), get_bloginfo( 'url' ) );
	}

	/**
	 * Add Home Crumb
	 */
	public function add_home_crumb() {
		$this->add_crumb( single_post_title( '', false ) );
	}

	/**
	 * Add Single Crumb
	 */
	public function add_single_crumb( $post_id = 0, $permalink = '' ) {
		if ( ! $post_id ) {
			global $post;
		} else {
			$post = get_post( $post_id ); // WPCS: override ok.
		}

		if ( ! $permalink ) {
			$permalink = get_permalink( $post );
		}

		if ( 'post' !== get_post_type( $post ) ) {
			$post_type = get_post_type_object( get_post_type( $post ) );

			if ( ! empty( $post_type->has_archive ) ) {
				$this->add_crumb( $post_type->labels->singular_name, get_post_type_archive_link( get_post_type( $post ) ) );
			}
		} else {
			$cat = current( get_the_category( $post ) );
			if ( $cat ) {
				$this->term_ancestors( $cat->term_id, 'category' );
				$this->add_crumb( $cat->name, get_term_link( $cat ) );
			}
		}

		$this->add_crumb( get_the_title( $post ), $permalink );
	}

	/**
	 * Add Page Crumb
	 */
	public function add_page_crumb() {
		$this->add_crumb( single_post_title( '', false ) );
	}

	/**
	 * Add Post Type Archive Crumb
	 */
	public function add_post_archive_crumb() {
		$this->add_crumb( single_post_title( '', false ) );
	}

	/**
	 * Add Archive Crumb
	 */
	public function add_archive_crumb() {
		$current_term  = get_term( $GLOBALS['wp_query']->get_queried_object() );
		$taxonomy      = get_taxonomy( $current_term->taxonomy );
		$taxonomy_name = $taxonomy->labels->singular_name;

		$this->add_crumb( $taxonomy_name, get_category_link( $current_term->term_id ) );

		if ( 0 !== intval( $current_term->parent ) ) {
			$this->term_ancestors( $current_term->term_id, 'category' );
		}

		$this->add_crumb( single_term_title( '', false ), get_category_link( $current_term->term_id ) );
	}

	// /**
	// * Add Category Crumb
	// */
	// public function add_category_crumb() {
	// $current_category = get_category( $GLOBALS['wp_query']->get_queried_object() );
	// jlog( $current_category );
	// $current_category = get_term( $GLOBALS['wp_query']->get_queried_object() );
	// jlog( $current_category );
	// $this->add_crumb( esc_html__( 'Category' ), get_category_link( $current_category->term_id ) );

	// if ( 0 !== intval( $current_category->parent ) ) {
	// $this->term_ancestors( $current_category->term_id, 'category' );
	// }

	// $this->add_crumb( single_cat_title( '', false ), get_category_link( $current_category->term_id ) );
	// }

	// /**
	// * Add Tag Crumb
	// */
	// public function add_tag_crumb() {
	// $current_category = get_term( $GLOBALS['wp_query']->get_queried_object() );
	// jlog( $current_category );
	// $this->add_crumb( single_post_title( '', false ) );
	// }

	// /**
	// * Add Taxonomy Crumb
	// */
	// public function add_taxonomy_crumb() {
	// $this->add_crumb( single_post_title( '', false ) );
	// }

	/**
	 * Add Author Crumb
	 */
	public function add_author_crumb() {
		global $author;

		$this->add_crumb( esc_html__( 'Author', 'profecient-essential' ), get_author_posts_url( $author ) );
		$this->add_crumb( get_the_author_meta( 'display_name', $author ) );
	}

	/**
	 * Add Date Crumb
	 */
	public function add_date_crumb() {
		if ( is_year() || is_month() || is_day() ) {
			$this->add_crumb( get_the_time( 'Y' ), get_year_link( get_the_time( 'Y' ) ) );
		}

		if ( is_month() || is_day() ) {
			$this->add_crumb( get_the_time( 'F' ), get_month_link( get_the_time( 'Y' ), get_the_time( 'm' ) ) );
		}

		if ( is_day() ) {
			$this->add_crumb( get_the_time( 'd' ), get_day_link( get_the_time( 'Y' ), get_the_time( 'm' ), get_the_time( 'd' ) ) );
		}
	}

	/**
	 * Add Search Crumb
	 */
	public function add_search_crumb() {
		$query_search = get_search_query();

		$this->add_crumb( esc_html__( 'Search', 'profecient-essential' ), get_search_link() );
		$this->add_crumb( esc_html( $query_search ), get_search_link( $query_search ) );
	}

	/**
	 * Add 404 Crumb
	 */
	protected function add_404_crumb() {
		$this->add_crumb( __( '404', 'profecient-essential' ) );
	}

	/**
	 * Add Attachment Crumb
	 */
	protected function add_attachment_crumb() {
		global $post;

		if ( ! $post->post_parent ) {
			$this->add_crumb( esc_html__( 'Attachment', 'profecient-essential' ), get_permalink() );
		} else {
			$this->add_single_crumb( $post->post_parent, get_permalink( $post->post_parent ) );
		}

		$this->add_crumb( get_the_title(), get_permalink() );
	}
}
