<?php
/**
 * Product Custom Add To Cart View Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Elements\Views;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Jeg\Elementor_Kit\Elements\Views\View_Abstract;

/**
 * Class Product_Custom_Add_To_Cart_View
 */
class Product_Custom_Add_To_Cart_View extends View_Abstract {
	/**
	 * Render Module
	 *
	 * @param  array  $attr         Array of attribute.
	 * @param  string $column_class Class string.
	 * @return string
	 */
	public function build_content() {
		global $product;

		$this->setup_hook();

		$temp_product = $product;
		$product      = wc_get_product( $this->attribute['sg_settings_selected_post'] );
		$button       = $product ? $this->build_button() : '';
		$classes      = 'profecient-product-custom-add-to-cart woocommerce ' . $this->unique_id;
		$product      = $temp_product;
		$button       = apply_filters( 'custom_product_add_to_cart', $button );

		$this->remove_hook();

		return '<div class="' . $classes . '">' . $button . '</div>';
	}

	/**
	 * Setup hook
	 */
	public function setup_hook() {
		add_filter( 'custom_product_add_to_cart', array( $this, 'render_cart_icon' ) );
	}

	/**
	 * Remove hook
	 */
	public function remove_hook() {
		remove_filter( 'custom_product_add_to_cart', array( $this, 'render_cart_icon' ) );
	}

	/**
	 * Build Button
	 *
	 * @return HTML
	 */
	public function build_button() {
		$button = null;

		$this->custom_add_to_cart_text( $this->attribute['sg_settings_custom_add_to_cart_text'] );

		if ( 'ajax' === $this->attribute['sg_settings_button_style'] ) {
			$button = $this->render_ajax_button();
		} elseif ( 'form' === $this->attribute['sg_settings_button_style'] ) {
			$button = $this->render_form_button();
		}

		return $button;
	}

	/**
	 * Custom Add To Cart Text
	 *
	 * @param string $custom_add_to_cart_text
	 */
	public function custom_add_to_cart_text( $custom_add_to_cart_text ) {
		if ( ! empty( $custom_add_to_cart_text ) ) {
			add_filter(
				'woocommerce_product_single_add_to_cart_text',
				function () use ( $custom_add_to_cart_text ) {
					return $custom_add_to_cart_text;
				}
			);
		}
	}

	/**
	 * Filter keys to ajax post request
	 *
	 * @return array
	 */
	public function get_ajax_param() {
		return array(
			'sg_filter_selected_post',
		);
	}

	/**
	 * Render Button
	 *
	 * @return HTML
	 */
	public function render_ajax_button() {
		global $product;

		if ( $product ) {
			$class = implode(
				' ',
				array(
					'button',
					'alt',
					'product_type_' . $product->get_type(),
					$product->is_purchasable() && $product->is_in_stock() ? 'add_to_cart_button' : '',
					$product->supports( 'ajax_add_to_cart' ) && $product->is_purchasable() && $product->is_in_stock() ? 'ajax_add_to_cart' : '',
				)
			);

			if ( $product->supports( 'ajax_add_to_cart' ) ) {
				$attributes = array(
					'data-product_id'  => $product->get_id(),
					'data-product_sku' => $product->get_sku(),
					'aria-label'       => $product->add_to_cart_description(),
					'rel'              => 'nofollow',
					'data-quantity'    => ! empty( $this->attribute['sg_settings_product_quantity'] ) ? $this->attribute['sg_settings_product_quantity'] : 1,
				);

				$html = sprintf(
					'<a href="%s" class="%s" %s><i class="fas fa-shopping-cart"></i> %s</a>',
					esc_url( $product->add_to_cart_url() ),
					$class,
					wc_implode_html_attributes( $attributes ),
					esc_html( $product->add_to_cart_text() )
				);
			} else {
				$attributes = array(
					'data-product_id'  => $product->get_id(),
					'data-product_sku' => $product->get_sku(),
					'aria-label'       => $product->add_to_cart_description(),
					'rel'              => 'nofollow',
				);

				$html = sprintf(
					'<a href="%s" class="%s" %s><i class="fas fa-shopping-cart"></i> %s</a>',
					esc_url( $product->add_to_cart_url() ),
					$class,
					wc_implode_html_attributes( $attributes ),
					esc_html( $product->add_to_cart_text() )
				);
			}

			return $html;
		}
	}

	/**
	 * Render Form Button
	 *
	 * @return HTML
	 */
	public function render_form_button() {
		ob_start();

		global $product;

		switch ( $product->get_type() ) {
			case 'simple':
				woocommerce_simple_add_to_cart(); /* Simple Add to Cart */
				break;
			case 'variable':
				woocommerce_variable_add_to_cart(); /* Variable Add to Cart */
				break;
			case 'external':
				woocommerce_external_add_to_cart(); /* External Add to Cart */
				break;
			case 'grouped':
				woocommerce_grouped_add_to_cart(); /* Grouped Add to Cart */
				break;
			default:
				woocommerce_template_single_add_to_cart(); /* Default Template */
				break;
		}

		$content = ob_get_clean();

		return $content;
	}

	/**
	 * Render Cart Icon
	 *
	 * @param string $content String of HTML
	 *
	 * @return string $content
	 */
	public function render_cart_icon( $content ) {
		if ( 'form' === $this->attribute['sg_settings_button_style'] ) {
			if ( isset( $this->attribute['sg_settings_button_icon']['value'] ) && ! empty( $this->attribute['sg_settings_button_icon']['value'] ) ) {
				$icon    = $this->render_icon_element( $this->attribute['sg_settings_button_icon'] );
				$content = preg_replace( '/(<button.*?>)(.*?)(<\/button>)|(<a[^<]+class=[\"\'][^<]*\sadd_to_cart_button\s*[^<]*[\"\'][^<]+>)(.*?)(<\/a>)/', '$1' . $icon . '$2$3', $content );
			}
		}

		if ( 'ajax' === $this->attribute['sg_settings_button_style'] ) {
			$icon = '';
			if ( isset( $this->attribute['sg_settings_button_icon']['value'] ) && ! empty( $this->attribute['sg_settings_button_icon']['value'] ) ) {
				$icon = $this->render_icon_element( $this->attribute['sg_settings_button_icon'] );
			}
			$content = preg_replace( '/(<a.*[$>])(<i.*[$>])(.*?<\/a>)/', '$1' . $icon . '$3', $content );
		}

		return $content;
	}
}
