<?php
/**
 * Woocommerce Account Page View Class
 *
 * @package profecient-essential
 * @author jegtheme
 * @since 1.0.0
 */

namespace Profecient\Essential\JKit\Elements\Views;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Jeg\Elementor_Kit\Elements\Views\View_WooCommerce_Abstract;

/**
 * Class Woocommerce_Account_Page_View
 */
class Woocommerce_Account_Page_View extends View_WooCommerce_Abstract {


	/**
	 * Build content for frontend editor
	 *
	 * @param string $name
	 *
	 * @return string
	 */
	public function build_content_frontend( $name ) {
		$this->page_template();
	}

	public function page_template( $is_editor = false ) {
		add_action( 'woocommerce_account_content', array( $this, 'before_account_content' ), 2 );
		add_action( 'woocommerce_account_content', array( $this, 'after_account_content' ), 95 );
		if ( ! $is_editor ) {
			$html = do_shortcode( '[woocommerce_my_account]' );

			echo '<div class="profecient-account-page-wrapper ' . esc_attr( $this->attribute['layout_type'] ) . '">' . $html . '</div>';
		} else {
			echo '<div class="profecient-account-page-wrapper ' . esc_attr( $this->attribute['layout_type'] ) . '">';
			$this->render_html_editor();
			echo '</div>';
		}
		remove_action( 'woocommerce_account_content', array( $this, 'before_account_content' ), 5 );
		remove_action( 'woocommerce_account_content', array( $this, 'after_account_content' ), 95 );
	}

	/**
	 * Before Account Content
	 *
	 * This eliminates the need for template overrides.
	 */
	public function before_account_content() {
		$wrapper_class = $this->get_account_content_wrapper( array( 'context' => 'frontend' ) );

		echo wp_kses( '<div class="' . esc_attr( $wrapper_class ) . '">', wp_kses_allowed_html() );
	}

	/**
	 * Get Account Pages
	 *
	 * @return array
	 */
	private function get_account_pages() {
		$pages = array(
			'dashboard'    => '',
			'orders'       => '',
			'downloads'    => '',
			'edit-address' => '',
		);

		// Check if payment gateways support add new payment methods.
		$support_payment_methods = false;
		foreach ( WC()->payment_gateways->get_available_payment_gateways() as $gateway ) {
			if ( $gateway->supports( 'add_payment_method' ) || $gateway->supports( 'tokenization' ) ) {
				$support_payment_methods = true;
				break;
			}
		}

		if ( $support_payment_methods ) {
			$pages['payment-methods'] = '';
		}

		// Edit account.
		$pages['edit-account'] = '';

		// Get the latest order (if there is one) for view-order (order preview) page.
		$recent_order = wc_get_orders(
			array(
				'limit'   => 1,
				'orderby' => 'date',
				'order'   => 'DESC',
			)
		);

		if ( ! empty( $recent_order ) ) {
			$pages['view-order'] = $recent_order[0]->get_id();
		}

		return $pages;
	}

	private function render_html_editor() {
		// Add .profecient-my-account-tab__dashboard as the default class when the editor loads.
		// This class will be replaced with JS when tabs are switched
		?>
		<div class="profecient-my-account-tab profecient-my-account-tab__dashboard">
			<span class="elementor-hidden">[[woocommerce_my_account]]</span>
			<div class="woocommerce">
			<?php
			if ( 'layout-2' === $this->attribute['layout_type'] ) {
				?>
				<div class="profecient-wc-account-tabs-nav">
					<?php wc_get_template( 'myaccount/navigation.php' ); ?>
				</div>
				<?php
			} else {
				wc_get_template( 'myaccount/navigation.php' );
			}

			// In the editor, output all the tabs in order to allow for switching between them via JS.
			$pages = $this->get_account_pages();

			global $wp_query;
			foreach ( $pages as $page => $page_value ) {
				foreach ( $pages as $unset_tab => $unset_tab_value ) {
					unset( $wp_query->query_vars[ $unset_tab ] );
				}
				$wp_query->query_vars[ $page ] = $page_value;

				$wrapper_class = $this->get_account_content_wrapper(
					array(
						'context' => 'editor',
						'page'    => $page,
					)
				);
				?>
				<div class="woocommerce-MyAccount-content" <?php echo esc_attr( $page ) ? 'profecient-my-account-page="' . esc_attr( $page ) . '"' : ''; ?>>
					<div class="<?php echo esc_attr( $wrapper_class ); ?>">
						<?php
						if ( 'dashboard' === $page ) {
							wc_get_template(
								'myaccount/dashboard.php',
								array(
									'current_user' => get_user_by( 'id', get_current_user_id() ),
								)
							);
						} else {
							do_action( 'woocommerce_account_' . $page . '_endpoint', $page_value );
						}
						?>
					</div>
				</div>
			<?php } ?>
			</div>
		</div>
		<?php
	}



		/**
		 * Get Account Content Wrapper
		 *
		 * @return string
		 */
	private function get_account_content_wrapper( $args ) {
		$user_id       = get_current_user_id();
		$num_orders    = wc_get_customer_order_count( $user_id );
		$num_downloads = count( wc_get_customer_available_downloads( $user_id ) );
		$class         = 'woocommerce-MyAccount-content-wrapper';

		if ( 'frontend' === $args['context'] ) { // Front-end display
			global $wp_query;
			if ( ( 0 === $num_orders && isset( $wp_query->query_vars['orders'] ) ) || ( 0 === $num_downloads && isset( $wp_query->query_vars['downloads'] ) ) ) {
				$class .= '-no-data';
			}
		} elseif ( ( 0 === $num_orders && 'orders' === $args['page'] ) || ( 0 === $num_downloads && 'downloads' === $args['page'] ) ) { // Editor display
				$class .= '-no-data';
		}

		return $class;
	}

	/**
	 * After Account Content
	 */
	public function after_account_content() {
		echo wp_kses( '</div>', wp_kses_allowed_html() );
	}

	/**
	 * Build content for backend editor
	 *
	 * @param string $name
	 *
	 * @return string
	 */
	public function build_content_backend( $name ) {
		$this->page_template( true );
	}

	/**
	 * Build block content
	 */
	public function build_content() {
		return $this->build_content_separately( 'profecient-woocommerce-cart-page' );
	}
}
