<?php
/**
 * Essential Framework Asset Class.
 *
 * @package essential-framework
 * @author jegtheme
 * @since 1.0.0
 */

namespace Essential\Framework;

use Essential\Framework\Options\Settings;
use Essential\Framework\Meta;

/**
 * Class Asset
 *
 * @package Essential\Framework\Assets
 */
class Asset {
	/**
	 * Class instance
	 *
	 * @var Asset
	 */
	private static $instance;

	/**
	 * Block ajax prefix
	 *
	 * @var string
	 */
	public static $element_ajax_prefix = 'essential_element_ajax_';

	/**
	 * Template Folder
	 *
	 * @var string
	 */
	protected $template_folder = ESSENTIAL_PARENT_DIR . 'template';

	/**
	 * Get class instance
	 *
	 * @return Asset
	 */
	public static function instance() {
		if ( null === static::$instance ) {
			static::$instance = new static();
		}

		return static::$instance;
	}

	/**
	 * Class constructor
	 */
	private function __construct() {
		$this->load_hook();
	}

	/**
	 * Load Hook
	 */
	private function load_hook() {
		add_action( 'wp_enqueue_scripts', array( $this, 'load_global_assets' ), 98 );
		add_action( 'wp_head', array( $this, 'load_custom_header_script' ) );
		add_action( 'wp_footer', array( $this, 'load_custom_footer_script' ) );
		add_action( 'elementor/editor/before_enqueue_scripts', array( $this, 'load_template_library_scripts' ) );
	}

	/**
	 * Load template library
	 */
	public function load_template_library_scripts() {
		$include = include ESSENTIAL_FRAMEWORK_DIR . '/lib/dependencies/template-library.asset.php';
		wp_enqueue_script(
			ESSENTIAL_FRAMEWORK . '-template-library',
			ESSENTIAL_FRAMEWORK_URL . '/assets/js/template-library.js',
			array_merge( $include['dependencies'], array( 'jquery', 'underscore', 'backbone-marionette' ) ),
			ESSENTIAL_FRAMEWORK_VERSION,
			true
		);
		wp_enqueue_style(
			ESSENTIAL_FRAMEWORK . '-template-library',
			ESSENTIAL_FRAMEWORK_URL . '/assets/css/library-styles.css',
			array(),
			ESSENTIAL_FRAMEWORK_VERSION
		);

		$this->fetch_template_library_data();

		wp_localize_script(
			ESSENTIAL_FRAMEWORK . '-template-library',
			$this->get_object_name( ESSENTIAL_FRAMEWORK . '-template-library-data', '-' ),
			array(
				'template' => $this->get_all_template(),
				'category' => $this->get_category(),
				'header'   => $this->get_header(),
				'page'     => $this->get_page(),
				'single'   => $this->get_single(),
				'section'  => $this->get_section(),
				'footer'   => $this->get_footer(),
				'favorite' => $this->get_favorite(),
				'path'     => $this->get_paths(),
			)
		);
	}

	/**
	 * Fetch Data
	 *
	 * @return void
	 */
	public function fetch_template_library_data() {
		$template_time = Meta::instance()->get_option( 'fetch_template_library_time' );
		$now           = time();

		if ( null === $template_time || $template_time < $now || apply_filters( 'fetch_template_library_data', false ) ) {
			$next_fetch = $now + ( 24 * 60 * 60 );
			Meta::instance()->set_option( 'fetch_template_library_time', $next_fetch );
			$this->update_template_library_data();
		}
	}

	/**
	 * Update Data.
	 */
	public function update_template_library_data() {
		$api_url  = essential_get_server_url() . '/v1/template-library/get-config';
		$args     = array(
			'sslverify' => false,
		);
		$response = wp_remote_get( $api_url, $args );
		if ( is_wp_error( $response ) ) {
			return false;
		}
		$data = wp_remote_retrieve_body( $response );

		Meta::instance()->set_option( 'template_library_data', json_decode( $data ) );
	}

	/**
	 * Generate Object Name
	 *
	 * @param string $name Name that will convert to object name.
	 * @param string $separator Separator use in name.
	 *
	 * @return string
	 */
	private function get_object_name( $name, $separator ) {
		$object_name = str_replace( ' ', '', ucwords( str_replace( $separator, ' ', $name ) ) );
		return $object_name;
	}

	/**
	 * Get Header Template
	 *
	 * @return array
	 */
	public function get_header() {
		$data = Meta::instance()->get_option( 'template_library_data' );
		return $data ? $data->header : array();
	}

	/**
	 * Get Header Template
	 *
	 * @return array
	 */
	public function get_paths() {
		$data = Meta::instance()->get_option( 'template_library_data' );
		return $data->paths;
	}

	/**
	 * Get Pages Template
	 *
	 * @return array
	 */
	public function get_page() {
		$data = Meta::instance()->get_option( 'template_library_data' );
		return $data ? $data->page : array();
	}

	/**
	 * Get Single Template
	 *
	 * @return array
	 */
	public function get_single() {
		$data = Meta::instance()->get_option( 'template_library_data' );
		return $data ? $data->single : array();
	}

	/**
	 * Get Section Template
	 *
	 * @return array
	 */
	public function get_section() {
		$data = Meta::instance()->get_option( 'template_library_data' );
		return $data ? $data->section : array();
	}

	/**
	 * Get Footer Template
	 *
	 * @return array
	 */
	public function get_footer() {
		$data = Meta::instance()->get_option( 'template_library_data' );
		return $data ? $data->footer : array();
	}

	/**
	 * Get Favorite Template
	 *
	 * @return array
	 */
	public function get_favorite() {
		$key     = 'essential_template_favorite';
		$user_id = get_current_user_id();

		return get_user_meta( $user_id, $key, true );
	}

	/**
	 * Get Template Category
	 *
	 * @return array
	 */
	public function get_category() {
		$data = Meta::instance()->get_option( 'template_library_data' );
		return $data ? $data->category : array();
	}

	/**
	 * Get all Template
	 *
	 * @return array
	 */
	public function get_all_template() {
		$data = Meta::instance()->get_option( 'template_library_data' );
		return $data ? $data->all_template : array();
	}

	/**
	 * Load custom header script
	 */
	public function load_custom_header_script() {
		$script = Settings::current_settings();

		if ( ! empty( $script['JCodeJSHead'] ) ) {
			$html       = strip_tags( $script['JCodeJSHead'] );
			$script_tag = "<script>$html</script>";
			echo essential_sanitize_output( $script_tag );
		}
	}

	/**
	 * Load custom header script
	 */
	public function load_custom_footer_script() {
		$script = Settings::current_settings();

		if ( ! empty( $script['JCodeJSFoot'] ) ) {
			$html       = strip_tags( $script['JCodeJSFoot'] );
			$script_tag = "<script>$html</script>";
			echo essential_sanitize_output( $script_tag );
		}
	}

	/**
	 * Load global assets
	 */
	public function load_global_assets() {
		$upload_dir = wp_upload_dir();
		if ( $upload_dir && $upload_dir['baseurl'] ) {
			wp_enqueue_style( 'essential-framework-global-style', $upload_dir['baseurl'] . '/' . ESSENTIAL_FRAMEWORK . '/' . ESSENTIAL_FRAMEWORK . '-global.css', array(), ESSENTIAL_FRAMEWORK_VERSION );
		}
	}

	/**
	 * Get Elementor custom settings
	 *
	 * @param string $name custom section name.
	 * @param string $settings options.
	 *
	 * @return array
	 */
	public static function get_elementor_custom_settings( $name, $settings = false ) {
		if ( ! is_array( $settings ) ) {
			$settings = self::get_elementor_page_settings();
		}
		$custom_settings = array();
		foreach ( $settings as $id => $value ) {
			if ( strpos( $id, $name ) !== false ) {
				$custom_settings[ $id ] = $value;
			}
		}

		return $custom_settings;
	}

	/**
	 * Get elementor page settings
	 *
	 * @return array
	 */
	public static function get_elementor_page_settings() {
		$settings = array();
		if ( defined( 'ELEMENTOR_VERSION' ) ) {
			$post_id = get_the_ID();

			$page_settings_manager = \Elementor\Core\Settings\Manager::get_settings_managers( 'page' );

			$page_settings_model = $page_settings_manager->get_model( $post_id );

			$settings = $page_settings_model->get_settings();
		}

		return $settings;
	}
}
