<?php
/**
 * Essential Framework Dashboard Class.
 *
 * @package essential-framework
 * @author jegtheme
 * @since 1.0.0
 */

namespace Essential\Framework;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Essential\Framework\Options\Settings;

/**
 * Class Dashboard.
 *
 * @package essential-framework
 */
class Dashboard {
	/**
	 * Class instance
	 *
	 * @var Dashboard
	 */
	private static $instance;

	/**
	 * Menu for dashboard
	 *
	 * @var array
	 */
	public static $framework_menu = array();

	/**
	 * Return class instance
	 *
	 * @return Dashboard
	 */
	public static function instance() {
		if ( null === static::$instance ) {
			static::$instance = new static();
		}

		return static::$instance;
	}

	/**
	 * Class constructor
	 */
	private function __construct() {
		$this->load_hook();
	}

	/**
	 * Load Hook
	 */
	private function load_hook() {
		add_action( 'admin_menu', array( $this, 'setup_parent_page' ) );
		add_action( 'admin_menu', array( $this, 'setup_child_page' ) );

		add_action( 'admin_enqueue_scripts', array( $this, 'enqueue_scripts' ) );
	}

	/**
	 * Initialize Menu
	 */
	public function define_menu() {
		self::$framework_menu['dashboard'] = array(
			'name'     => esc_html__( 'Dashboard', 'profecient-theme' ),
			'priority' => 49,
			'type'     => 'menu',
		);

		self::$framework_menu['demos'] = array(
			'name'     => esc_html__( 'Import Demos', 'profecient-theme' ),
			'priority' => 50,
			'type'     => 'menu',
		);

		if ( defined( 'ELEMENTOR_VERSION' ) ) {
			self::$framework_menu['theme-option'] = array(
				'name'     => esc_html__( 'Theme Option', 'profecient-theme' ),
				'priority' => 50,
				'type'     => 'menu',
			);
		}

		self::$framework_menu['system-status'] = array(
			'name'     => esc_html__( 'System Status', 'profecient-theme' ),
			'priority' => 70,
			'type'     => 'menu',
		);

		self::$framework_menu['need-help'] = array(
			'name'     => esc_html__( 'Need Help?', 'profecient-theme' ),
			'priority' => 80,
			'type'     => 'url',
			'url'      => 'https://themeforest.net/user/jegtheme',
		);

		$this->get_template_list();

		self::$framework_menu = apply_filters( 'essential_framework_dashboard_item', self::$framework_menu );
	}

	/**
	 * Get Template List
	 */
	public function get_template_list() {
		if ( class_exists( '\Jeg\Elementor_Kit\Dashboard\Dashboard' ) ) {

			self::$framework_menu['theme-builder'] = array(
				'name'     => esc_html__( 'Theme Builder', 'profecient-theme' ),
				'priority' => 60,
				'type'     => 'url',
				'url'      => get_home_url() . '/wp-admin/admin.php?page=jkit-header',
			);

			$menus = \Jeg\Elementor_Kit\Dashboard\Dashboard::instance()->get_admin_menu();

			foreach ( $menus as $key => $menu ) {
				if ( isset( $menu['parent'] ) && 'jkit-manage-template' === $menu['parent'] ) {
					self::$framework_menu[ $menu['slug'] ] = array(
						'name'     => $menu['title'],
						'priority' => $menu['priority'],
						'type'     => 'url',
						'url'      => get_home_url() . '/wp-admin/admin.php?page=' . $menu['slug'],
						'parent'   => 'theme-builder',
					);
				}
			}
		}
	}

	/**
	 * Setup parent page menu
	 */
	public function setup_parent_page() {
		$this->define_menu();
		add_menu_page( ESSENTIAL_PARENT_NAME, ESSENTIAL_PARENT_NAME, 'edit_theme_options', ESSENTIAL_PARENT, null, 'none', 3.001 );
	}

	/**
	 * Get child pages
	 *
	 * @return void
	 */
	public function setup_child_page() {
		$path    = admin_url( 'admin.php?page=' . ESSENTIAL_PARENT . '&path=' );
		$subpath = '&subpath=';
		$pages   = array();

		foreach ( self::$framework_menu as $key => $menu ) {
			if ( $menu ) {
				$pages[] = array(
					'title'    => $menu['name'],
					'menu'     => $menu['name'],
					'slug'     => 'url' === $menu['type'] ? $menu['url'] : $path . $key,
					'position' => $menu['priority'],
				);
				if ( 1 === count( $pages ) ) {
					$pages[ count( $pages ) - 1 ]['slug']     = ESSENTIAL_PARENT;
					$pages[ count( $pages ) - 1 ]['callback'] = array( $this, 'dashboard_page' );
				}
				if ( isset( $menu['parent'] ) ) {
					$pages[ count( $pages ) - 1 ]['class'] = 'essential-framework-child-menu';
					$pages[ count( $pages ) - 1 ]['slug']  = 'url' === $menu['type'] ? $menu['url'] : $path . $menu['parent'] . $subpath . $key;
				}
			}
		}

		/** Sorting Page menus by Positions */
		usort(
			$pages,
			function ( $a, $b ) {
				$menu_a = floatval( $a['position'] );
				$menu_b = floatval( $b['position'] );

				if ( $menu_a < $menu_b ) {
					return -1;
				} elseif ( $menu_a > $menu_b ) {
					return 1;
				} else {
					return 0;
				}
			}
		);

		foreach ( $pages as $key => $page ) {
			add_submenu_page(
				ESSENTIAL_PARENT,
				$page['title'],
				$page['menu'],
				'edit_theme_options',
				$page['slug'],
				isset( $page['callback'] ) ? $page['callback'] : ''
			);
			$this->add_child_menu_class( $key, $page );
		}
	}

	/**
	 * Add Class Selector to Child Menu
	 *
	 * @param int   $key Menu offset.
	 * @param array $menu List of menu.
	 */
	private function add_child_menu_class( $key, $menu ) {
		global $submenu;

		if ( isset( $menu['class'] ) ) {
			// @codingStandardsIgnoreStart
			$submenu[ ESSENTIAL_PARENT ][ $key ][4] = $menu['class'];
			// @codingStandardsIgnoreEnd
		}
	}

	/**
	 * Enqueue scripts
	 *
	 * @param string $hook .
	 */
	public function enqueue_scripts( $hook ) {
		$register_location = array(
			'post.php',
			'toplevel_page_' . ESSENTIAL_PARENT,
		);

		wp_enqueue_style(
			ESSENTIAL_FRAMEWORK . '-dashboard',
			ESSENTIAL_FRAMEWORK_URL . '/assets/css/dashboard-styles.css',
			array(),
			ESSENTIAL_FRAMEWORK_VERSION
		);

		if ( in_array( $hook, $register_location, true ) ) {
			$include                 = include ESSENTIAL_FRAMEWORK_DIR . '/lib/dependencies/dashboard.asset.php';
			$include                 = apply_filters( 'essential_include_dashboard', $include );
			$name_translation_object = $this->get_object_name( ESSENTIAL_FRAMEWORK . '-dashboard-text', '-' );
			$name_option_object      = $this->get_object_name( ESSENTIAL_FRAMEWORK . '-dashboard-option', '-' );
			$option_object           = wp_json_encode( $this->get_all_option() );

			wp_enqueue_media();

			wp_enqueue_script(
				ESSENTIAL_FRAMEWORK . '-dashboard',
				ESSENTIAL_FRAMEWORK_URL . '/assets/js/dashboard.js',
				array_merge( $include['dependencies'], array( 'media-upload' ) ),
				ESSENTIAL_FRAMEWORK_VERSION,
				true
			);

			wp_localize_script(
				ESSENTIAL_FRAMEWORK . '-dashboard',
				$name_translation_object,
				$this->get_all_text()
			);

			wp_add_inline_script( ESSENTIAL_FRAMEWORK . '-dashboard', "var {$name_option_object} = {$option_object};" );
		}
	}

	/**
	 * Generate Object Name
	 *
	 * @param string $name Name that will convert to object name.
	 * @param string $separator Separator use in name.
	 *
	 * @return string
	 */
	private function get_object_name( $name, $separator ) {
		$object_name = str_replace( ' ', '', ucwords( str_replace( $separator, ' ', $name ) ) );
		return $object_name;
	}

	/**
	 * Get all option
	 *
	 * @return array
	 */
	private function get_all_option() {
		return array(
			'homeSlug'         => ESSENTIAL_FRAMEWORK,
			'menus'            => self::$framework_menu,
			'globalOptions'    => Settings::current_settings(),
			'imgDir'           => ESSENTIAL_FRAMEWORK_URL . '/assets/img/',
			'plugins'          => self::list_plugin(),
			'system'           => self::system_status(),
			'optionInfo'       => self::get_option_info(),
			'fontList'         => Fonts::get_formated_font_list(),
			'activeBreakpoint' => essential_get_elementor_responsive_breakpoints(),
			'activeTemplate'   => wp_get_theme()->get_page_templates(),
			'themeMenu'        => self::get_theme_option_menu(),
			'homeUrl'          => get_home_url(),
			'apiUrl'           => essential_get_server_url(),
			'root'             => ESSENTIAL_PARENT,
		);
	}

	/**
	 * Get option info
	 *
	 * @return array
	 */
	private function get_option_info() {
		$option_info = array(
			'JColorPrimary'          => array(
				'title'       => 'Primary Color',
				'description' => 'This dominant color is used throughout most of website.',
			),
			'JColorSecondary'        => array(
				'title'       => 'Secondary Color',
				'description' => 'This color is used for hover effects or secondary design on website.',
			),
			'JColorText'             => array(
				'title'       => 'Text Color',
				'description' => 'This color used for all text elements on the website.',
			),
			'JColorAccent'           => array(
				'title'       => 'Accent Color',
				'description' => 'This color is used to highlight important elements on the website.',
			),
			'JColorTertiary'         => array(
				'title'       => 'Tertiary Color',
				'description' => 'Create nuances and variations to make the appearance more interesting.',
			),
			'JColorMeta'             => array(
				'title'       => 'Meta Color',
				'description' => 'Basically this color is used in meta (date, author, etc.).',
			),
			'JColorBorder'           => array(
				'title'       => 'Border Color',
				'description' => 'Create a more beautiful border and make your elements clearer.',
			),
			'JFontPrimary'           => array(
				'title'       => 'Primary',
				'description' => 'This font will be used for the title or headline on your web page.',
			),
			'JFontSecondary'         => array(
				'title'       => 'Secondary',
				'description' => 'This font is used to provide emphasis such as keywords on a web page.',
			),
			'JFontText'              => array(
				'title'       => 'Body',
				'description' => 'This is the font used for paragraph and main content on websites.',
			),
			'JFontAccent'            => array(
				'title'       => 'Accent',
				'description' => 'This font provides interesting design variations and contrasts with body.',
			),
			'JFontTextMenu'          => array(
				'title'       => 'Text Menu',
				'description' => 'This font is used specifically for menu elements on website.',
			),
			'JFontTextButton'        => array(
				'title'       => 'Text Button',
				'description' => 'This font is used specifically for all button elements on the website.',
			),
			'JFontTextHero'          => array(
				'title'       => 'Text Hero',
				'description' => 'Generally, this font is used in the hero description section.',
			),
			'JFontTextFooter'        => array(
				'title'       => 'Text Footer',
				'description' => 'The font used in footers that contain additional information, important links, or copyright.',
			),
			'JFontBlogTitle'         => array(
				'title'       => 'Blog Title',
				'description' => 'This font is used to create a special visual identity for your blog.',
			),
			'JFontIconBoxTitle'      => array(
				'title'       => 'Icon Box Title',
				'description' => 'Refers to the font used for titles or labels that usually accompany icons.',
			),
			'JFontPricingTitle'      => array(
				'title'       => 'Pricing Title',
				'description' => 'Used to display price information, packages, or cost details on a website.',
			),
			'JFontStepTitle'         => array(
				'title'       => 'Step Title',
				'description' => 'This font is used for stages, tutorials or processes explained on a website.',
			),
			'JTypographyBody'        => array(
				'title'       => 'Body',
				'description' => 'The aim is to create an easy-to-read text display on the website.',
			),
			'JTypographyLink'        => array(
				'title'       => 'Link',
				'description' => 'Used for links that have not been or have been clicked.',
			),
			'JTypographyH1'          => array(
				'title'       => 'H1',
				'description' => 'Used to determine the main title of a web page.',
			),
			'JTypographyH2'          => array(
				'title'       => 'H2',
				'description' => 'Used to determine a title that is hierarchically lower than H1.',
			),
			'JTypographyH3'          => array(
				'title'       => 'H3',
				'description' => 'Used to determine the heading that is below H2 in the hierarchy.',
			),
			'JTypographyH4'          => array(
				'title'       => 'H4',
				'description' => 'Used to determine the heading that is below H3 in the hierarchy.',
			),
			'JTypographyH5'          => array(
				'title'       => 'H5',
				'description' => 'Used to determine the heading that is below H4 in the hierarchy.',
			),
			'JTypographyH6'          => array(
				'title'       => 'H6',
				'description' => 'Used for the most specific subheadings or title elements.',
			),
			'JButtonsTypography'     => array(
				'title'       => 'Typography',
				'description' => 'Set the typography style for your button font.',
			),
			'JButtonsTextShadow'     => array(
				'title'       => 'Text Shadow',
				'description' => 'Increase the variety and aesthetics of the text on your button.',
			),
			'JButtonsPadding'        => array(
				'title'       => 'Padding',
				'description' => 'Set additional spaces to create a better, more balanced appearance of the button.',
			),
			'JButtonsTextColor'      => array(
				'title'       => 'Text Color',
				'description' => 'Set the color to use for the text inside the button.',
			),
			'JButtonsBackground'     => array(
				'title'       => 'Background',
				'description' => 'Set the visual effect by determining the color of the background.',
			),
			'JButtonsBoxShadow'      => array(
				'title'       => 'Box Shadow',
				'description' => 'Creates a shadow or penumbra around the button.',
			),
			'JButtonsBorderType'     => array(
				'title'       => 'Border',
				'description' => 'Create prettier borders and make your button clearer.',
			),
			'JImagesOpacity'         => array(
				'title'       => 'Opacity',
				'description' => 'Set the transparency effect to a value of 0 or 1 on the image.',
			),
			'JImagesBoxShadow'       => array(
				'title'       => 'Box Shadow',
				'description' => 'Creates a shadow or penumbra around the image.',
			),
			'JImagesCSSFilter'       => array(
				'title'       => 'CSS Filter',
				'description' => 'It is used to apply visual effects, such as grayscale, blur and saturation.',
			),
			'JImagesHoverTransition' => array(
				'title'       => 'Hover Transition',
				'description' => 'Hover transition time.',
			),
			'JImagesBorder'          => array(
				'title'       => 'Border',
				'description' => 'Create prettier borders and make your image clearer.',
			),
			'JFormLabelTypography'   => array(
				'title'       => 'Label Typography',
				'description' => 'Set typography and color on your form label.',
			),
			'JFormTypography'        => array(
				'title'       => 'Text Field',
				'description' => 'Set typography to enter certain information into a form.',
			),
			'JFormTextColor'         => array(
				'title'       => 'Text Color',
				'description' => 'Increase the variety and aesthetics of the text on your form.',
			),
			'JFormAccentColor'       => array(
				'title'       => 'Accent Color',
				'description' => 'This color is used to highlight important elements on the form.',
			),
			'JFormBackgroundColor'   => array(
				'title'       => 'Background',
				'description' => 'Set the background color of the form to make it more attractive.',
			),
			'JFormBoxShadow'         => array(
				'title'       => 'Box Shadow',
				'description' => 'Creates a shadow or penumbra around the form.',
			),
			'JFormBorderType'        => array(
				'title'       => 'Border Type',
				'description' => 'Create prettier borders and make your form clearer.',
			),
			'JFormPadding'           => array(
				'title'       => 'Padding',
				'description' => 'Set additional spaces to create a better, more balanced appearance of the form.',
			),
			'JSiteName'              => array(
				'title'       => 'Site Name',
				'description' => 'Start branding by giving your website a unique name.',
			),
			'JSiteDescription'       => array(
				'title'       => 'Site Description',
				'description' => 'This description can help the website appear in relevant search results.',
			),
			'JSiteLogo'              => array(
				'title'       => 'Logo Site',
				'description' => 'Set the default logo.',
			),
			'JSiteFavico'            => array(
				'title'       => 'Favicon Site',
				'description' => 'Set icons for browser tabs. Recommended size: 80 pixels x 80 pixels.',
			),
			'JLayoutContentWidth'    => array(
				'title'       => 'Content Width Layout',
				'description' => 'Arrange the layout to limit the width of the content to maintain readability.',
			),
			'JLayoutWidgetsSpace'    => array(
				'title'       => 'Content Space Layout',
				'description' => 'Arrange this layout to create an open, clean look.',
			),
			'JLayoutTitleSelector'   => array(
				'title'       => 'Title Selector Layout',
				'description' => 'Create a visual hierarchy with the title as the main focus.',
			),
			'JLayoutStretchSection'  => array(
				'title'       => 'Stretch Section Layout',
				'description' => 'This is to fill the entire width of the screen with specific content.',
			),
			'JLayoutPageLayout'      => array(
				'title'       => 'Page Layout',
				'description' => 'Set the layout to arrange the elements more organized.',
			),
			'JLayoutBreakpoints'     => array(
				'title'       => 'Active Breakpoints',
				'description' => 'Arrange and adjust the display on various screen sizes.',
			),
			'JBackgroundBackground'  => array(
				'title'       => 'Background',
				'description' => 'Choice of website background color to make it more attractive.',
			),
			'JBackgroundMobile'      => array(
				'title'       => 'Mobile Browser Background',
				'description' => 'Set the mobile background color on your website.',
			),
			'JCodeCSS'               => array(
				'title'       => 'Custom CSS',
				'description' => 'Take full control Customize your website design in greater detail with custom CSS.',
			),
			'JCodeJSHead'            => array(
				'title'       => 'Custom JS Header',
				'description' => 'Add functionality to your web header with custom JavaScript.',
			),
			'JCodeJSFoot'            => array(
				'title'       => 'Custom JS Footer',
				'description' => 'Add functionality to your web footer with custom JavaScript.',
			),
			'JAdditionalCursor'      => array(
				'title'       => 'Custom Cursor',
				'description' => 'Enable the Custom Cursor feature. To turn it off, simply disable this option.',
			),
		);

		return $option_info;
	}

	/**
	 * Get Formated Font List
	 */
	public function get_theme_option_menu() {
		$menu = array(
			array(
				'menu'    => 'DESIGN SYSTEM',
				'submenu' => array(
					array(
						'title' => 'Global Colors',
						'slug'  => 'global-colors',
					),
					array(
						'title' => 'Global Fonts',
						'slug'  => 'global-fonts',
					),
				),
			),
			array(
				'menu'    => 'THEME STYLE',
				'submenu' => array(
					array(
						'title' => 'Typography',
						'slug'  => 'typography',
					),
					array(
						'title' => 'Buttons',
						'slug'  => 'buttons',
					),
					array(
						'title' => 'Images',
						'slug'  => 'images',
					),
					array(
						'title' => 'Forms',
						'slug'  => 'forms',
					),
					// array(
					// 'title' => 'Header',
					// 'slug'  => 'header',
					// ),
					// array(
					// 'title' => 'Footer',
					// 'slug'  => 'footer',
					// ),
				),
			),
			array(
				'menu'    => 'SETTINGS',
				'submenu' => array(
					array(
						'title' => 'Site Identity',
						'slug'  => 'site-identity',
					),
					array(
						'title' => 'Layout',
						'slug'  => 'layout',
					),
					array(
						'title' => 'Background',
						'slug'  => 'background',
					),
					// array(
					// 'title' => 'Social',
					// 'slug'  => 'social',
					// ),
					// array(
					// 'title' => 'Animations',
					// 'slug'  => 'animations',
					// ),
					array(
						'title' => 'Custom Code',
						'slug'  => 'custom-code',
					),
					array(
						'title' => 'Additional Settings',
						'slug'  => 'additional-setting',
					),
				),
			),
		);

		return apply_filters( 'essential_get_theme_option_menu', $menu );
	}

	/**
	 * System Status.
	 *
	 * @return array
	 */
	public function system_status() {
		$status = array();

		/** Themes */
		$theme                    = wp_get_theme();
		$parent                   = wp_get_theme( get_template() );
		$status['theme_name']     = $theme->get( 'Name' );
		$status['theme_version']  = $theme->get( 'Version' );
		$status['is_child_theme'] = is_child_theme();
		$status['parent_theme']   = $parent->get( 'Name' );
		$status['parent_version'] = $parent->get( 'Version' );

		/** WordPress Environment */
		$wp_upload_dir              = wp_upload_dir();
		$status['home_url']         = home_url( '/' );
		$status['site_url']         = site_url();
		$status['login_url']        = wp_login_url();
		$status['wp_version']       = get_bloginfo( 'version', 'display' );
		$status['is_multisite']     = is_multisite();
		$status['wp_debug']         = defined( 'WP_DEBUG' ) && WP_DEBUG;
		$status['memory_limit']     = ini_get( 'memory_limit' );
		$status['wp_memory_limit']  = WP_MEMORY_LIMIT;
		$status['wp_language']      = get_locale();
		$status['writeable_upload'] = wp_is_writable( $wp_upload_dir['basedir'] );
		$status['count_category']   = wp_count_terms( 'category' );
		$status['count_tag']        = wp_count_terms( 'post_tag' );

		/** Server Environment */
		$remote     = wp_remote_get( 'http://api.wordpress.org/plugins/update-check/1.1/', array( 'body' => array( 'plugins' => wp_json_encode( array() ) ) ) );
		$gd_support = array();

		if ( function_exists( 'gd_info' ) ) {
			foreach ( gd_info() as $key => $value ) {
				$gd_support[ $key ] = $value;
			}
		}

		$status['server_info']        = sanitize_text_field( wp_unslash( essential_server_software() ) );
		$status['php_version']        = PHP_VERSION;
		$status['post_max_size']      = ini_get( 'post_max_size' );
		$status['max_input_vars']     = ini_get( 'max_input_vars' );
		$status['max_execution_time'] = ini_get( 'max_execution_time' );
		$status['suhosin']            = extension_loaded( 'suhosin' );
		$status['imagick']            = extension_loaded( 'imagick' );
		$status['gd']                 = extension_loaded( 'gd' ) && function_exists( 'gd_info' );
		$status['gd_webp']            = extension_loaded( 'gd' ) && $gd_support['WebP Support'];
		$status['fileinfo']           = extension_loaded( 'fileinfo' ) && ( function_exists( 'finfo_open' ) || function_exists( 'mime_content_type' ) );
		$status['curl']               = extension_loaded( 'curl' ) && function_exists( 'curl_version' );
		$status['wp_remote_get']      = ! is_wp_error( $remote ) && $remote['response']['code'] >= 200 && $remote['response']['code'] < 300;

		/** Plugins */
		$status['plugins'] = $this->data_active_plugin();

		return $status;
	}

	/**
	 * Data active plugin
	 *
	 * @return array
	 */
	public function data_active_plugin() {
		$active_plugin = array();

		$plugins = array_merge(
			array_flip( (array) get_option( 'active_plugins', array() ) ),
			(array) get_site_option( 'active_sitewide_plugins', array() )
		);

		$plugins = array_intersect_key( get_plugins(), $plugins );

		if ( count( $plugins ) > 0 ) {
			foreach ( $plugins as $plugin ) {
				$item                = array();
				$item['uri']         = isset( $plugin['PluginURI'] ) ? esc_url( $plugin['PluginURI'] ) : '#';
				$item['name']        = isset( $plugin['Name'] ) ? $plugin['Name'] : esc_html__( 'unknown', 'profecient-theme' );
				$item['author_uri']  = isset( $plugin['AuthorURI'] ) ? esc_url( $plugin['AuthorURI'] ) : '#';
				$item['author_name'] = isset( $plugin['Author'] ) ? $plugin['Author'] : esc_html__( 'unknown', 'profecient-theme' );
				$item['version']     = isset( $plugin['Version'] ) ? $plugin['Version'] : esc_html__( 'unknown', 'profecient-theme' );

				$content = esc_html__( 'by', 'profecient-theme' );

				$active_plugin[] = array(
					'type'            => 'status',
					'title'           => $item['name'],
					'content'         => $content,
					'link'            => $item['author_uri'],
					'link_text'       => $item['author_name'],
					'additional_text' => $item['version'],
				);
			}
		}

		return $active_plugin;
	}

	/**
	 * Get List Of Installed Plugin.
	 *
	 * @return array
	 */
	public static function list_plugin() {
		$plugins = array();
		$active  = array();

		foreach ( get_option( 'active_plugins' ) as  $plugin ) {
			$active[] = explode( '/', $plugin )[0];
		}

		foreach ( get_plugins() as $key => $plugin ) {
			$slug             = explode( '/', $key )[0];
			$data             = array();
			$data['active']   = in_array( $slug, $active, true );
			$data['version']  = $plugin['Version'];
			$data['name']     = $plugin['Name'];
			$data['path']     = str_replace( '.php', '', $key );
			$plugins[ $slug ] = $data;
		}

		return $plugins;
	}

	/**
	 * Get all text
	 *
	 * @return array
	 */
	private function get_all_text() {
		return array(
			'general' => array(
				'get_started' => __( 'Get Started', 'profecient-theme' ),
			),
		);
	}

	/**
	 * Load dashboard page
	 */
	public function dashboard_page() {
		?>
		<div id="essential-framework-dashboard"></div>
		<div id="essential-framework-dashboard-import"></div>
		<?php
	}
}
