<?php
/**
 * Sync class
 *
 * @package essential-framework
 * @author jegtheme
 * @since 1.0.0
 */

namespace Essential\Framework\Elementor;

use Essential\Framework\Meta;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Class Sync.
 *
 * @package essential-framework
 */
class Sync {
	/**
	 * Class instance
	 *
	 * @var Sync
	 */
	private static $instance;

	/**
	 * Return class instance
	 *
	 * @return Sync
	 */
	public static function instance() {
		if ( null === static::$instance ) {
			static::$instance = new static();
		}

		return static::$instance;
	}

	/**
	 * Class constructor
	 */
	private function __construct() {
		add_filter( 'add_post_metadata', array( '\Essential\Framework\Elementor\Sync', 'sync_with_elementor' ), 20, 5 );
		add_filter( 'update_post_metadata', array( '\Essential\Framework\Elementor\Sync', 'sync_with_elementor' ), 20, 5 );
		Meta::instance()->set_option( 'no_sync', false );
	}

	/**
	 * We will sync Elementor global option with our theme_option.
	 *
	 * Short-circuits updating metadata of a specific type.
	 *
	 * @param null|bool $check      Whether to allow updating metadata for the given type.
	 * @param int       $object_id  ID of the object metadata is for.
	 * @param string    $meta_key   Metadata key.
	 * @param mixed     $value Metadata value. Must be serializable if non-scalar.
	 * @param mixed     $prev_value Optional. Previous value to check before updating.
	 *                              If specified, only update existing metadata entries with
	 *                              this value. Otherwise, update all entries.
	 *
	 * @return null|bool
	 */
	public static function sync_with_elementor( $check, $object_id, $meta_key, $value, $prev_value ) {
		if ( Meta::instance()->get_option( 'no_sync' ) ) {
			return $check;
		}
		$kit_id = (int) get_option( 'elementor_active_kit' );
		if ( $object_id === $kit_id && '_elementor_page_settings' === $meta_key ) {
			$current_settings = array(); // @TODO: Where we will store the current Setting ?
			$is_essential     = apply_filters( 'essential_doing_save_theme_option', false );
			$the_filter       = current_filter();
			// Global colors
			$global_colors = array(
				array(
					'option' => 'JColorP',
					'id'     => 'essential_primary',
					'name'   => 'Primary',
				),
				array(
					'option' => 'JColorS',
					'id'     => 'essential_secondary',
					'name'   => 'Secondary',
				),
				array(
					'option' => 'JColorA',
					'id'     => 'essential_accent',
					'name'   => 'Accent',
				),
				array(
					'option' => 'JColorH',
					'id'     => 'essential_headline',
					'name'   => 'Headline',
				),
				array(
					'option' => 'JColorB',
					'id'     => 'essential_body',
					'name'   => 'Body',
				),
				array(
					'option' => 'JColorD',
					'id'     => 'essential_dark',
					'name'   => 'Dark Neutral',
				),
				array(
					'option' => 'JColorL',
					'id'     => 'essential_light',
					'name'   => 'Light Neutral',
				),
				array(
					'option' => 'JColorW',
					'id'     => 'essential_white',
					'name'   => 'White',
				),
			);

			// register global color to system color elementor.
			foreach ( $global_colors as $id => $color ) {
				if ( ! $is_essential ) {
					$to_set                               = $value['system_colors'][ $id ]['color'];
					$current_settings[ $color['option'] ] = $to_set;
				} else {
					$value['system_colors'][ $id ]['color'] = $current_settings[ $color['option'] ];
					$value['system_colors'][ $id ]['_id']   = $color['id'];
					$value['system_colors'][ $id ]['name']  = $color['name'];
				}
			}

			$global_fonts = array(
				array(
					'option' => 'JFontP',
					'id'     => 'essential_primary',
					'name'   => 'Primary',
				),
				array(
					'option' => 'JFontS',
					'id'     => 'essential_secondary',
					'name'   => 'Secondary',
				),
				array(
					'option' => 'JFontB',
					'id'     => 'essential_body',
					'name'   => 'Body',
				),
				array(
					'option' => 'JFontA',
					'id'     => 'essential_accent',
					'name'   => 'Accent',
				),
				array(
					'option' => 'JFontTM',
					'id'     => 'essential_text_menu',
					'name'   => 'Text Menu',
				),
				array(
					'option' => 'JFontTB',
					'id'     => 'essential_text_button',
					'name'   => 'Text Button',
				),
				array(
					'option' => 'JFontTH',
					'id'     => 'essential_text_hero',
					'name'   => 'Text Hero',
				),
				array(
					'option' => 'JFontTF',
					'id'     => 'essential_text_footer',
					'name'   => 'Text Footer',
				),
				array(
					'option' => 'JFontBT',
					'id'     => 'essential_text_box_title',
					'name'   => 'Text Box Title',
				),
				array(
					'option' => 'JFontIBT',
					'id'     => 'essential_text_icon_box_title',
					'name'   => 'Text Icon Box Title',
				),
				array(
					'option' => 'JFontPT',
					'id'     => 'essential_text_pricing_title',
					'name'   => 'Text Pricing Title',
				),
				array(
					'option' => 'JFontST',
					'id'     => 'essential_text_step_title',
					'name'   => 'Text Step Title',
				),
			);

			foreach ( $global_fonts as $id => $font ) {
				if ( ! $is_essential ) {
					$to_set                              = array(
						'font-family' => $value['system_typography'][ $id ]['typography_font_family'],
						'font-weight' => $value['system_typography'][ $id ]['typography_font_weight'],
					);
					$current_settings[ $font['option'] ] = $to_set;
				} else {
					$value['system_typography'][ $id ] = array(
						'_id'                    => $font['id'],
						'title'                  => 'Essential - Font ' . implode( ' ', preg_split( '/(?=[A-Z])/', preg_replace( '/([a-z])([A-Z])/', '$1 $2', $font['name'] ) ) ),
						'typography_font_family' => $current_settings[ $font['option']['font-family'] ],
						'typography_font_weight' => $current_settings[ $font['option']['font-weight'] ],
						'typography_typography'  => 'custom',
					);
				}
			}

			if ( ! $is_essential ) {
				self::direct_save_meta( $the_filter, $object_id, $meta_key, $value, $prev_value );
				$check = $value;

				$new_settings = array(); // @TODO: Where we will update the new Setting ?
			}
		} elseif ( $object_id === $kit_id && '_elementor_css' === $meta_key ) {
			$elementor_settings = get_post_meta( $kit_id, '_elementor_page_settings', true );

			if ( ! $elementor_settings ) {
				// @TODO: Where we will update the setting to our setting
			}
		}
		return $check;
	}

	/**
	 * Save to meta without get fitered by hook.
	 *
	 * @param string $filter The save meta filter.
	 * @param int    $object_id  ID of the object metadata is for.
	 * @param string $meta_key   Metadata key.
	 * @param mixed  $meta_value Metadata value. Must be serializable if non-scalar.
	 * @param mixed  $unique_or_prev_value Previous value to check before updating or Whether the specified metadata key should be unique for the object.
	 */
	public static function direct_save_meta( $filter, $object_id, $meta_key, $meta_value, $unique_or_prev_value ) {
		$prev_value = $unique_or_prev_value;
		$unique     = $unique_or_prev_value;
		Meta::instance()->set_option( 'no_sync', true );

		if ( 'add_post_metadata' === $filter ) {
			add_metadata( 'post', $object_id, $meta_key, $meta_value, $unique );
		} elseif ( 'update_post_metadata' === $filter ) {
			update_metadata( 'post', $object_id, $meta_key, $meta_value, $prev_value );
		}
	}
}
